##
##  wasmtime.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2025 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_base  34.0.0
%define       V_snap  20250620

#   package information
Name:         wasmtime
Summary:      WebAssembly Runtime
URL:          https://wasmtime.dev/
Vendor:       Bytecode Alliance
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Web
License:      MIT
Version:      %{V_base}
Release:      20250620

#   list of sources
Source0:      http://download.openpkg.org/components/versioned/wasmtime/wasmtime-%{V_snap}.tar.xz

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, rust, cmake, make
PreReq:       OpenPKG, openpkg >= 20160101

%description
    WASMtime is a small and efficient runtime for WebAssembly and WASI.
    WASMtime implements the standards-track WASM-C-API.

%track
    prog wasmtime = {
        version   = %{V_base}
        url       = https://github.com/bytecodealliance/wasmtime/releases
        regex     = /v(\d+\.\d+\.\d+)\.tar\.gz
    }

%prep
    %setup -q -n wasmtime

%build
    HOME=`pwd`
    cargo fetch
    cargo build --release
    ( cd crates/c-api
      cmake \
          -Wno-dev \
          -DCMAKE_BUILD_TYPE="Release" \
          -DCMAKE_INSTALL_PREFIX="%{l_prefix}" \
          -DCMAKE_C_COMPILER="%{l_cc}" \
          -DCMAKE_C_FLAGS="%{l_cflags} %{l_cppflags}" \
          -DCMAKE_EXE_LINKER_FLAGS="%{l_ldflags}" \
          -DCMAKE_CXX_COMPILER="%{l_cxx}" \
          .
      %{l_make} %{l_mflags}
   ) || exit $?

%install
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/bin \
        $RPM_BUILD_ROOT%{l_prefix}/include/wasmtime \
        $RPM_BUILD_ROOT%{l_prefix}/lib
    %{l_shtool} install -c -m 755 \
        target/release/wasmtime \
        $RPM_BUILD_ROOT%{l_prefix}/bin/
    %{l_shtool} install -c -m 644 \
        crates/c-api/include/w*.h \
        $RPM_BUILD_ROOT%{l_prefix}/include/
    %{l_shtool} install -c -m 644 \
        crates/c-api/include/wasmtime/*.h \
        $RPM_BUILD_ROOT%{l_prefix}/include/wasmtime/
    %{l_shtool} install -c -m 644 \
        target/*-*/release/libwasmtime.a \
        $RPM_BUILD_ROOT%{l_prefix}/lib/
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

